@@ -33,7 +33,7 @@
 #|
 \section{Database structure}
 In order to understand this program you need to understand some details
-of the structure of the databases it reads. Axiom has 5 databases,
+of the structure of the databases it reads. FriCAS has 5 databases,
 the interp.daase, operation.daase, category.daase, compress.daase, and
 browse.daase. The compress.daase is special and does not follow the
 normal database format.
@@ -301,40 +301,41 @@ database.
 (defvar |$all_constructors| nil "a list of all the constructors in the system")
 (defvar |$all_operations| nil "a list of all the operations in the system")
 
-(defvar |$asharp_flags| "-O -laxiom -Fasy -Flsp" "library compiler flags")
+(defvar |$asharp_flags| "-O -lfricas -Fasy -Flsp" "library compiler flags")
 
 (defun asharp (file &optional (flags |$asharp_flags|))
- "call the asharp compiler"
+ "call the aldor compiler"
  (#| system::system |#
    obey
-   (concatenate 'string (|getEnv| "AXIOM") "/compiler/bin/axiomxl "
+   (concatenate 'string (|getEnv| "FRICAS") "/compiler/bin/aldor "
     flags " " file)))
 
-(defun resethashtables ()
+(defun resethashtables (display_messages)
  "set all *_hash to clean values. used to clean up core before saving system"
  (setq |$has_category_hash| (make-hash-table :test #'equal))
  (setq |$operation_hash| (make-hash-table))
  (setq |$all_constructors| nil)
  (setq |$compress_vector| nil)
  (setq |$compress_stream_stamp| '(0 . 0))
- (|compressOpen|)
+ (|compressOpen| display_messages)
  (setq |$interp_stream_stamp| '(0 . 0))
- (|interpOpen|)
+ (|interpOpen| display_messages)
  (setq |$operation_stream_stamp| '(0 . 0))
- (|operationOpen|)
+ (|operationOpen| display_messages)
  (setq |$browse_stream_stamp| '(0 . 0))
- (|browseOpen|)
+ (|browseOpen| display_messages)
  (setq |$category_stream_stamp| '(0 . 0))
- (|categoryOpen|) ;note: this depends on constructorform in browse.daase
- (initial-getdatabase)
+ ;note: this depends on constructorform in browse.daase
+ (|categoryOpen| display_messages)
+ (initial-getdatabase display_messages)
  (close |$interp_stream|)
  (close |$operation_stream|)
  (close |$category_stream|)
  (close |$browse_stream|)
-#+:GCL (LISP::gbc t)
+#+:GCL (SI::gbc t)
 )
 
-(defun initial-getdatabase ()
+(defun initial-getdatabase (display_messages)
  "fetch data we want in the saved system"
  (let (hascategory constructormodemapAndoperationalist operation constr)
  (format t "Initial getdatabase~%")
@@ -346,7 +347,7 @@ database.
   (|Fraction| . |Algebra|) (|Fraction| . |CoercibleTo|)
   (|Fraction| . |OrderedSet|) (|Fraction| . |RetractableTo|)
   (|Integer| . |Algebra|) (|Integer| . |CoercibleTo|)
-  (|Integer| . |ConvertibleTo|) (|Integer| . |LinearlyExplicitRingOver|)
+  (|Integer| . |ConvertibleTo|) (|Integer| . |LinearlyExplicitOver|)
   (|Integer| . |RetractableTo|)
   (|List| . |CoercibleTo|) (|List| . |FiniteLinearAggregate|)
   (|List| . |OrderedSet|)
@@ -392,7 +393,7 @@ database.
   |UnivariatePolynomialCategory&| |FlexibleArray|
   |SparseMultivariatePolynomial| |PolynomialCategory&|
   |DifferentialExtension&| |IndexedFlexibleArray| |AbelianMonoidRing&|
-  |FiniteAbelianMonoidRing&| |DivisionRing&| |FullyLinearlyExplicitRingOver&|
+  |FiniteAbelianMonoidRing&| |DivisionRing&| |FullyLinearlyExplicitOver&|
   |IndexedVector| |IndexedOneDimensionalArray| |LocalAlgebra| |Localize|
   |Boolean| |Field&| |Vector| |IndexedDirectProductObject| |Aggregate&|
   |PolynomialRing| |FreeModule| |IndexedDirectProductAbelianGroup|
@@ -411,16 +412,21 @@ database.
   |Integer| |List| |OutputForm|))
  (dolist (con constr)
   (let ((c (concatenate 'string
-             (|getEnv| "AXIOM") "/algebra/"
+             (|getEnv| "FRICAS") "/algebra/"
              (string (getdatabase con 'abbreviation)) "." |$lisp_bin_filetype|)))
-    (format t "   preloading ~a.." c)
+    (if display_messages
+        (format t "   preloading ~a.." c))
     (if (probe-file c)
-     (progn
-      (put con 'loaded c)
-      (load c)
-      (format t "loaded.~%"))
-     (format t "skipped.~%"))))
- (format t "~%")))
+        (progn
+            (put con 'loaded c)
+            (load c)
+            (if display_messages
+                (format t "loaded.~%")))
+      (if display_messages
+          (format t "skipped.~%")))))
+ (if display_messages
+     (format t "~%")))
+)
 
 ; format of an entry in interp.daase:
 ;  (constructor-name
@@ -438,13 +444,14 @@ database.
 ;    defaultdomain       -- a short list, for %i
 ;    ancestors           -- used to compute new category updates
 ;  )
-(defun |interpOpen| ()
+(defun |interpOpen| (display_messages)
  "open the interpreter database and hash the keys"
  (let (constructors pos stamp dbstruct)
   (setq |$interp_stream| (open (DaaseName "interp.daase")))
   (setq stamp (read |$interp_stream|))
   (unless (equal stamp |$interp_stream_stamp|)
-   (format t "   Re-reading interp.daase")
+   (if display_messages
+       (format t "   Re-reading interp.daase"))
 
    ; Clean old data
    (do-symbols (symbol)
@@ -501,13 +508,14 @@ database.
 ;     predicates
 ; )
 
-(defun |browseOpen| ()
+(defun |browseOpen| (display_messages)
  "open the constructor database and hash the keys"
  (let (constructors pos stamp dbstruct)
   (setq |$browse_stream| (open (DaaseName "browse.daase")))
   (setq stamp (read |$browse_stream|))
   (unless (equal stamp |$browse_stream_stamp|)
-   (format t "   Re-reading browse.daase")
+   (if display_messages
+       (format t "   Re-reading browse.daase"))
    (setq |$browse_stream_stamp| stamp)
    (setq pos (car stamp))
    (file-position |$browse_stream| pos)
@@ -516,7 +524,7 @@ database.
     (setq item (unsqueeze item))
     (unless (setq dbstruct (get (car item) 'database))
      (format t "browseOpen:~%")
-     (format t "the browse database contains a contructor ~a~%" item)
+     (format t "the browse database contains a constructor ~a~%" item)
      (format t "that is not in the interp.daase file. we cannot~%")
      (format t "get the database structure for this constructor and~%")
      (warn "will create a new one~%")
@@ -529,13 +537,14 @@ database.
     (setf (database-parents dbstruct) (sixth item))))
   (format t "~&")))
 
-(defun |categoryOpen| ()
+(defun |categoryOpen| (display_messages)
  "open category.daase and hash the keys"
  (let (pos keys stamp)
   (setq |$category_stream| (open (DaaseName "category.daase")))
   (setq stamp (read |$category_stream|))
   (unless (equal stamp |$category_stream_stamp|)
-   (format t "   Re-reading category.daase")
+   (if display_messages
+       (format t "   Re-reading category.daase"))
    (setq |$category_stream_stamp| stamp)
    (setq pos (car stamp))
    (file-position |$category_stream| pos)
@@ -546,13 +555,14 @@ database.
     (setf (gethash (first item) |$has_category_hash|) (second item))))
   (format t "~&")))
 
-(defun |operationOpen| ()
+(defun |operationOpen| (display_messages)
  "read operation database and hash the keys"
  (let (operations pos stamp)
   (setq |$operation_stream| (open (DaaseName "operation.daase")))
   (setq stamp (read |$operation_stream|))
   (unless (equal stamp |$operation_stream_stamp|)
-   (format t "   Re-reading operation.daase")
+   (if display_messages
+       (format t "   Re-reading operation.daase"))
    (setq |$operation_stream_stamp| stamp)
    (setq pos (car stamp))
    (file-position |$operation_stream| pos)
@@ -605,8 +615,6 @@ database.
   (getdatabase constructor 'niladic))
  (format t "~a: ~a~%" 'abbreviation
   (getdatabase constructor 'abbreviation))
- (format t "~a: ~a~%" 'constructor?
-  (getdatabase constructor 'constructor?))
  (format t "~a: ~a~%" 'constructor
   (getdatabase constructor 'constructor))
  (format t "~a: ~a~%" 'defaultdomain
@@ -657,8 +665,7 @@ database.
 (defun getdatabase (constructor key)
  (declare (special $spadroot) (special |$miss|))
  (when (eq |$miss| t) (format t "getdatabase call: ~20a ~a~%" constructor key))
- (let (data table stream ignore struct)
-  (declare (ignore ignore))
+ (let (data table stream struct)
   (when (or (symbolp constructor)
           (and (eq key 'hascategory) (pairp constructor)))
   (case key
@@ -713,9 +720,6 @@ database.
     (setq stream |$interp_stream|)
     (when (setq struct (get constructor 'database))
      (setq data (database-niladic struct))))
-   (constructor?
-    (when (setq struct (get constructor 'database))
-      (setq data (when (database-operationalist struct) t))))
    (superdomain ; only 2 superdomains in the world
     (case constructor
      (|NonNegativeInteger|
@@ -834,24 +838,23 @@ database.
     (values only dir noexpose)))
 
   (processDir (dirarg thisdir)
-      (let (nrlibdirs asos skipasos aos)
+      (let (nrlibdirs skipasos aos)
 
       (chdir (string dirarg))
-      #-:GCL
+;      #-:GCL
       (setq nrlibdirs (directory "*.NRLIB/index.KAF"))
 
       #| directory in GCL (at least gcl-2.6.8) on Windows is buggy,
       it can not handle pathnames having wildcards in the middle,
       so we need a workaround.  |#
-      #+:GCL
-      (setq nrlibdirs
-           (mapcar #'(lambda (f)
-                          (concatenate 'string (namestring f)
-                                         "/index.KAF"))
-                   (directory "*.NRLIB")))
+;      #+:GCL
+;      (setq nrlibdirs
+;           (mapcar #'(lambda (f)
+;                          (concatenate 'string (namestring f)
+;                                         "/index.KAF"))
+;                   (directory "*.NRLIB")))
 
       (setq asys (directory "*.asy"))
-      (setq asos (directory "*.ao"))
 
       (setq skipasos (mapcan #'pathname-name asys))
 
@@ -909,7 +912,8 @@ database.
    (asharp file)
    (setq file (|astran| (concatenate 'string (pathname-name file) ".asy")))
    (localasy file object only make-database? noexpose))
-  (CLRHASH |$ConstructorCache|))))
+  (|clearConstructorCaches|))
+))
 
 (defun localasy (asy object only make-database? noexpose)
  "given an alist from the asyfile and the objectfile update the database"
@@ -968,8 +972,8 @@ database.
         (setq kind (database-constructorkind dbstruct))
         (if (null noexpose) (|setExposeAddConstr| (cons cname nil)))
         (unless make-database?
-         (|updateDatabase| key cname systemdir?) ;makes many hashtables???
-         (|installConstructor| cname kind)
+         (|updateDatabase| cname) ;makes many hashtables???
+         (|installConstructor| cname)
           ;; following can break category database build
          (if (eq kind '|category|)
              (setf (database-ancestors dbstruct)
@@ -1043,8 +1047,8 @@ database.
    (if (eq kind '|category|)
        (setf (database-ancestors dbstruct)
              (SUBLISLIS |$FormalMapVariableList| (cdr constructorform) (fetchdata alist in "ancestors"))))
-   (|updateDatabase| key key systemdir?) ;makes many hashtables???
-   (|installConstructor| key kind) ;used to be key cname ...
+   (|updateDatabase| key) ;makes many hashtables???
+   (|installConstructor| key) ;used to be key cname ...
    (|updateCategoryTable| key kind)
    (if |$InteractiveMode| (setq |$CategoryFrame| |$EmptyEnvironment|)))
   (setf (database-cosig dbstruct)
@@ -1191,13 +1195,14 @@ database.
 ;; into the compress database. In this way long symbol names become
 ;; short negative numbers.
 
-(defun |compressOpen| ()
+(defun |compressOpen| (display_messages)
  (let (lst stamp pos)
   (setq |$compress_stream|
     (open (DaaseName "compress.daase") :direction :input))
   (setq stamp (read |$compress_stream|))
   (unless (equal stamp |$compress_stream_stamp|)
-   (format t "   Re-reading compress.daase")
+   (if display_messages
+       (format t "   Re-reading compress.daase"))
    (setq |$compress_stream_stamp| stamp)
    (setq pos (car stamp))
    (file-position |$compress_stream| pos)
@@ -1315,7 +1320,7 @@ database.
 
 (defun write-browsedb ()
  "make browse.daase from hash tables"
- (let (master masterpos src formpos docpos attpos predpos (*print-pretty* t) out)
+ (let (master masterpos src formpos docpos predpos (*print-pretty* t) out)
   (print "building browse.daase")
   (setq out (open "browse.build" :direction :output :if-exists :supersede))
   (princ "                              " out)
@@ -1366,37 +1371,10 @@ database.
   #+:GCL (force-output out)
   (close out)))
 
-(defun unsqueeze (expr)
-  (cond ((atom expr)
-         (cond ((and (numberp expr) (< expr 0))
-                (svref |$compress_vector| (- expr)))
-               (t expr)))
-        (t (rplaca expr (unsqueeze (car expr)))
-           (rplacd expr (unsqueeze (cdr expr)))
-           expr)))
 
-(defun squeeze (expr)
-  (if |$do_not_compress_databases|
-    expr
-    (let (leaves pos (bound (length |$compress_vector|)))
-     (labels (
-      (flat (expr)
-       (when (and (numberp expr) (< expr 0))
-        (print expr)
-        (break "squeeze found a negative number"))
-       (if (atom expr)
-        (unless (or (null expr)
-                    (and (symbolp expr) (char= (schar (symbol-name expr) 0) #\*)))
-         (setq leaves (adjoin expr leaves)))
-        (progn
-         (flat (car expr))
-         (flat (cdr expr))))))
-     (setq leaves nil)
-     (flat expr)
-     (dolist (leaf leaves)
-      (when (setq pos (position leaf |$compress_vector|))
-        (nsubst (- pos) leaf expr)))
-     expr))))
+(defun unsqueeze (expr) expr)
+
+(defun squeeze (expr) expr)
 
 (defun write-operationdb ()
  (let (pos master out (*print-pretty* t))
@@ -1429,25 +1407,25 @@ database.
  |$all_operations|)
 
 ; the variable NOPfuncall is a funcall-able object that is a dummy
-; initializer for libaxiom asharp domains.
+; initializer for libfricas aldor domains.
 (defvar NOPfuncall (cons 'identity nil))
 
 (defun |createInitializers| ()
-;; since libaxiom is now built with -name=axiom following unnecessary
+;; since libfricas is now built with -name=fricas following unnecessary
 ;; (dolist (con (|allConstructors|))
 ;;   (let ((sourcefile (getdatabase con 'sourcefile)))
 ;;     (if sourcefile
 ;;       (set (foam::axiomxl-file-init-name (pathname-name sourcefile))
 ;;             NOPfuncall))))
- (set (foam::axiomxl-file-init-name "axiom") NOPfuncall)
+ (set (foam::axiomxl-file-init-name "fricas") NOPfuncall)
 ;; (set (foam::axiomxl-file-init-name "axclique") NOPfuncall)
  (set (foam::axiomxl-file-init-name "filecliq") NOPfuncall)
  (set (foam::axiomxl-file-init-name "attrib") NOPfuncall)
  (|createInitializers2|))
 
-;; following needs to happen inside restart since $AXIOM may change
+;; following needs to happen inside restart since $FRICAS may change
 (defun |createInitializers2| ()
- (let ((asharprootlib (strconc (|getEnv| "AXIOM") "/aldor/lib/")))
+ (let ((asharprootlib (strconc (|getEnv| "FRICAS") "/aldor/lib/")))
    (set-file-getter (strconc asharprootlib "runtime"))
    (set-file-getter (strconc asharprootlib "lang"))
    (set-file-getter (strconc asharprootlib "attrib"))
@@ -1461,7 +1439,7 @@ database.
 
 ; how the magic works:
 ;  when a )library is done on a new compiler file we set up multiple
-;  functions (refered to as autoloaders). there is an autoloader
+;  functions (referred to as autoloaders). there is an autoloader
 ;  stored in the symbol-function of the G-filename (e.g. G-basic)
 ;  (see set-file-getter function)
 ;  and an autoloader stored in the symbol-function of every domain
@@ -1598,7 +1576,7 @@ database.
          (bootname (intern stringname 'boot)))
     (declare (ignore libname))
     (if (and (eq hcode 'foam-user::|initializer|) (not (boundp asharpname)))
-        (error (format nil "AxiomXL file ~s is missing!" stringname)))
+        (error (format nil "Aldor file ~s is missing!" stringname)))
     (unless (or (not (numberp hcode)) (zerop hcode) (boundp asharpname))
           (when (|constructor?| bootname)
                 (set asharpname
