@@ -141,6 +141,7 @@
                    ((IDENTP V) NIL)
                    ((STRINGP U) (AND (STRINGP V) (string> V U)))
                    ((STRINGP V) NIL)
+                   ((BREAK))
                    ((AND (VECP U) (VECP V))
                     (AND (> (SIZE V) (SIZE U))
                          (DO ((I 0 (1+ I)))
@@ -172,10 +173,8 @@
       ((NULL COMPERAND-1) 'T )
       ((NULL COMPERAND-2) NIL)
       ((VECP COMPERAND-1)
-        (COND
-          ((VECP COMPERAND-2) (LEXVGREATERP COMPERAND-1 COMPERAND-2) )
-          ('else t)))
-      ((VECP COMPERAND-2) NIL)
+        (BREAK))
+      ((VECP COMPERAND-2) (BREAK))
       ((stringp COMPERAND-1)
         (COND
           ((stringp COMPERAND-2)
@@ -200,33 +199,9 @@
             (CHAR-GREATERP COMPERAND-1 COMPERAND-2) )
           ('else t)))
       ((CHARACTERP COMPERAND-2) NIL )
-      ((FBPIP COMPERAND-1)
-        (COND
-          ((FBPIP COMPERAND-2)
-            (LEXGREATERP (BPINAME COMPERAND-1) (BPINAME COMPERAND-2)) )
-          ('else t)))
-      ((FBPIP COMPERAND-2) NIL)
+      (BREAK)
       ((> (SXHASH COMPERAND-1) (SXHASH COMPERAND-2)))))
 
-(DEFUN LEXVGREATERP (VECTOR-COMPERAND-1 VECTOR-COMPERAND-2)
-  (declare (simple-vector vector-comperand-1 vector-comperand-2))
-    (PROG ((L1 (length VECTOR-COMPERAND-1))
-           (L2 (length VECTOR-COMPERAND-2))
-           (I -1)
-           T1 T2)
-     (declare (fixnum i l1 l2) )
-  LP  (setq i (1+ i))
-      (COND
-        ((EQL L1 I) (RETURN NIL))
-        ((EQL L2 I) (RETURN 'T)))
-      (COND
-        ((EQUAL
-            (SETQ T1 (svref VECTOR-COMPERAND-1 I))
-            (SETQ T2 (svref VECTOR-COMPERAND-2 I)))
-          (GO LP)))
-      (RETURN (LEXGREATERP T1 T2)) ) )
-
-
 (DEFUN GGREATERP (COMPERAND-1 COMPERAND-2)
     ;;  "Order of types: symbol pair NIL vec string num fbpi other"
     (COND
@@ -251,7 +226,8 @@
       ((VECP COMPERAND-1)
         (COND
           ((VECP COMPERAND-2) (VGREATERP COMPERAND-1 COMPERAND-2) )
-          ('else t)))
+          ('else t))
+      )
       ((VECP COMPERAND-2) NIL)
       ((stringp COMPERAND-1)
         (COND
@@ -271,14 +247,9 @@
             (CHAR> COMPERAND-1 COMPERAND-2) )
           ('else t)))
       ((CHARACTERP COMPERAND-2) NIL )
-      ((FBPIP COMPERAND-1)
-        (COND
-          ((FBPIP COMPERAND-2)
-            (GGREATERP (BPINAME COMPERAND-1) (BPINAME COMPERAND-2)) )
-          ('else t)))
-      ((FBPIP COMPERAND-2) NIL)
       ((> (SXHASH COMPERAND-1) (SXHASH COMPERAND-2)))))
 
+;;; Would like to remove this but is is used in PartialFraction
 (DEFUN VGREATERP (VECTOR-COMPERAND-1 VECTOR-COMPERAND-2)
   (declare (simple-vector vector-comperand-1 vector-comperand-2))
     (PROG ((L1 (length VECTOR-COMPERAND-1))
@@ -324,16 +295,6 @@
 
 ; 15.2 Lists
 
-(defun ELEMN (X N DEFAULT)
-  (COND ((NULL X) DEFAULT)
-        ((EQL N 1) (CAR X))
-        ((ELEMN (CDR X) (- N 1) DEFAULT))))
-
-(defun LISTOFATOMS (X)
-  (COND ((NULL X) NIL)
-        ((ATOM X) (LIST X))
-        ((NCONC (LISTOFATOMS (CAR X)) (LISTOFATOMS (CDR X))))))
-
 (DEFUN LASTATOM (L) (if (ATOM L) L (LASTATOM (CDR L))))
 
 (defun DROP (N X &aux m)
@@ -373,27 +334,6 @@
 
 ; 15.5 Using Lists as Sets
 
-;;; The [[CONTAINED]] predicate is used to walk internal structures
-;;; such as modemaps to see if the $X$ object occurs within $Y$. One
-;;; particular use is in a function called [[isPartialMode]] (see
-;;; i-funsel.boot) to decide
-;;; if a modemap is only partially complete. If this is true then the
-;;; modemap will contain the constant [[$EmptyMode]]. So the call
-;;; ends up being [[CONTAINED |$EmptyMode| Y]].
-(DEFUN CONTAINED (X Y)
-  (if (symbolp x)
-      (contained\,eq X Y)
-      (contained\,equal X Y)))
-
-(defun contained\,eq (x y)
-       (if (atom y) (eq x y)
-           (or (contained\,eq x (car y)) (contained\,eq x (cdr y)))))
-
-(defun contained\,equal (x y)
-   (cond ((atom y) (equal x y))
-         ((equal x y) 't)
-         ('t (or (contained\,equal x (car y)) (contained\,equal x (cdr y))))))
-
 (DEFUN |set_sum| (X Y)
   (COND ((ATOM Y) X)
         ((ATOM X) Y)
@@ -426,7 +366,7 @@
         ((CONS (CAR L) (ADDASSOC X Y (CDR L))))))
 
 (DEFUN DELLASOS (U V)
-  "Remove any assocation pair (U . X) from list V."
+  "Remove any association pair (U . X) from list V."
   (COND ((ATOM V) NIL)
         ((EQUAL U (CAAR V)) (CDR V))
         ((CONS (CAR V) (DELLASOS U (CDR V))))))
@@ -458,11 +398,11 @@
 ; (defun QLASSQ (p a-list) (let ((y (assoc p a-list :test #'eq))) (if y (cdr y))))
 (defun QLASSQ (p a-list) (cdr (assq p a-list)))
 
-(defun pair (x y) (mapcar #'cons x y))
+(defun MAKE_PAIRS (x y) (mapcar #'cons x y))
 
 ;;; Operations on Association Sets (AS)
 
-(defun AS-INSERT (A B L)
+(defun AS_INSERT (A B L)
     (let ((pp (assoc A L :test #'equal)))
         (if pp
             (progn
@@ -489,19 +429,8 @@
 
 (defun |get_lisp_error_out| () *error-output*)
 
-(defparameter |$fricasOutput| (make-synonym-stream '*standard-output*))
-
-(defun |sayMSG2File| (msg)
-  (PROG (file str)
-        (SETQ file (|makePathname| '|spadmsg| '|listing|))
-        (SETQ str (MAKE_OUTSTREAM file))
-        (|sayBrightly1| msg str)
-        (SHUT str) ) )
-
 (defvar |$fortranOutputStream|)
 
-(defvar |$formulaOutputStream|)
-
 (defvar |$highlightAllowed| nil "Used in BRIGHTPRINT and is a )set variable.")
 
 (defvar |$highlightFontOn| (concat " " |$boldString|)
@@ -542,7 +471,7 @@
 
 ; 25 MISCELLANEOUS FEATURES
 
-(defun MAKE-REASONABLE (Z)
+(defun MAKE_REASONABLE (Z)
    (if (> (length Z) 30) (CONCAT "expression beginning " (subseq Z 0 20)) Z))
 
 (defun DROPTRAILINGBLANKS  (LINE)
@@ -615,13 +544,6 @@
 (DEFUN |rightBindingPowerOf| (X IND &AUX (Y (GET X IND)))
    (IF Y (ELEMN Y 4 105) 105))
 
-(defun |make_BF| (MT EP) (LIST |$BFtag| MT EP))
-
-(defun |make_float| (int frac fraclen exp)
-    (if (= frac 0)
-          (|make_BF| int exp)
-          (|make_BF| (+ (* int (expt 10 fraclen)) frac) (- exp fraclen)) ))
-
 (defun |print_full2| (expr stream)
    (let ((*print-circle* t) (*print-array* t) *print-level* *print-length*)
      (print expr stream)
@@ -631,57 +553,45 @@
 
 ;; moved here from preparse.lisp
 
-(defun NEXT-TAB-LOC (i) (* (1+ (truncate i 8)) 8))
+(defvar tab-size-in-spaces 8
+  "How many spaces do we consider a #\Tab character?")
 
-(defun INDENT-POS (STR)
-  (do ((i 0 (1+ i))
-       (pos 0))
-      ((>= i (length str)) nil)
-      (case (char str i)
-            (#\space (incf pos))
-            (#\tab (setq pos (next-tab-loc pos)))
-            (otherwise (return pos)))))
+(defun NEXT-TAB-LOC (i)
+  "Given a character position I, on what position would a #\Tab land
+us?"
+  (* tab-size-in-spaces (1+ (truncate i tab-size-in-spaces))))
 
-;;(defun expand-tabs (str)
-;;  (let ((bpos (nonblankloc str))
-;;      (tpos (indent-pos str)))
-;;    (if (eql bpos tpos) str
-;;      (concatenate 'string (make-string tpos :initial-element #\space)
-;;                 (subseq str bpos)))))
-(defun expand-tabs (str)
-   (if (and (stringp str) (> (length str) 0))
-      (let ((bpos (nonblankloc str))
-            (tpos (indent-pos str)))
-        (setq str
-              (if (eql bpos tpos)
-                  str
-                  (concatenate 'string
-                               (make-string tpos :initial-element #\space)
-                               (subseq str bpos))))
-        (loop
-            (let ((tloc (tabloc str)))
-                (if (null tloc) (return))
-                (let ((rloc (NEXT-TAB-LOC tloc)))
-                    (if (eql tloc rloc)
-                        (setf (aref str tloc) #\Space)
-                        (setf str
-                            (concatenate 'string
-                                (subseq str 0 tloc)
-                                (make-string (+ 1 (- rloc tloc))
-                                    :initial-element #\space)
-                                (subseq str (+ 1 tloc))))))))
-         ;; remove dos CR
-        (let ((lpos (maxindex str)))
-          (if (eq (char str lpos) #\Return) (subseq str 0 lpos) str)))
-    str))
+(defun EXPAND_TABS (str)
+  "Given a string STR, expand all #\Tab characters to spaces, minding
+the correct column each #\Tab would carry us to.
 
-(defun blankp (char) (or (eq char #\Space) (eq char #\tab)))
-
-(defun nonblankloc (str) (position-if-not #'blankp str))
-
-(defun tabp (c) (equal c #\tab))
-
-(defun tabloc (str) (position-if #'tabp str))
+This function respects intermediate #\Newline characters and drops
+#\Return characters."
+  (cond
+    ((stringp str)
+     (with-output-to-string (s)
+       (loop :with column := 0
+             :for c :across str
+             :do (case c
+                   (#\Tab
+                    ;; How many spaces does our tab carry us forward
+                    ;; by?
+                    (let ((num-spaces (- (next-tab-loc column) column)))
+                      (incf column num-spaces)
+                      ;; This format string just writes something N
+                      ;; times without consing up garbage.
+                      (format s "~v@{~C~:*~}" num-spaces #\Space)))
+                   (#\Newline
+                    (setf column 0)
+                    (write-char #\Newline s))
+                   (#\Return
+                    ;; Drop this character completely.
+                    nil)
+                   (t
+                    (incf column)
+                    (write-char c s))))))
+    (t
+     str)))
 
 ;; stream handling for paste-in generation
 
@@ -691,7 +601,7 @@
   (let* ((*standard-output* (make-string-output-stream))
          (curoutstream *standard-output*)
          (*error-output* *standard-output*)
-         (|$algebraOutputStream| *standard-output*)
+         (|$algebraOutputStream| (CONS NIL *standard-output*))
         val)
     (declare (special curoutstream
                       |$algebraOutputStream|))
@@ -757,7 +667,7 @@
 ; NAME:    Debugging Package
 ; PURPOSE: Debugging hooks for Boot code
 
-(defun enable-backtrace (&rest arg))
+(defun ENABLE_BACKTRACE (&rest arg))
 
 (defun |adjoin_equal|(x y) (ADJOIN x y :test #'equal))
 
