@@ -41,11 +41,8 @@
 #+(and :GCL :IEEE-FLOATING-POINT)
   (setq system:*print-nans* T)
 
-(setq |$algebraOutputStream|
-      (setq |$fortranOutputStream|
-            (setq |$texOutputStream|
-                  (setq |$formulaOutputStream|
-                        (make-synonym-stream '*standard-output*)))))
+;;; In case 'setvart.boot' does not work...
+(setq |$algebraOutputStream| (|mkOutputConsoleStream|))
 
 (defvar |$frameMessages| nil)
 (defvar |$displayStartMsgs| nil)
@@ -90,7 +87,6 @@
 
 
 (SETQ $SPAD_ERRORS (VECTOR 0 0 0))
-(SETQ $OLDLINE NIL)  ;"used to output command lines"
 (SETQ |$edit_file| NIL)
 (DEFPARAMETER |$InteractiveMode| T)
 
@@ -232,7 +228,7 @@
        (|recurrence| . "set functions recurrence")
        (|restore|    . "history )restore")
        (|save|       . "history )save")
-       (|startGraphics|    .  "system $AXIOM/lib/viewman &")
+       (|startGraphics|    .  "system $FRICAS/lib/viewman &")
        (|stopGraphics|     .  "lisp (|sockSendSignal| 2 15)")
        (|time|       . "set message time")
        (|type|       . "set message type")
@@ -246,28 +242,28 @@
 
 (SETQ |$CommandSynonymAlist| (COPY |$InitialCommandSynonymAlist|))
 
-(DEFPARAMETER |$ConstructorCache| (MAKE_HASHTABLE 'ID))
-(SETQ |$instantRecord| (MAKE_HASHTABLE 'ID))
+(DEFPARAMETER |$ConstructorCache| (MAKE_HASHTABLE 'EQ))
+(SETQ |$instantRecord| (MAKE_HASHTABLE 'EQ))
 (SETQ |$immediateDataSymbol| '|--immediateData--|)
 
 (SETQ |$useIntegerSubdomain| 'T)
 
 ;; See CLAMMED BOOT for defs of following functions
 (SETQ |$clamList| '(
-  (|canCoerce| |hash| UEQUAL |count|)
-  (|canCoerceFrom| |hash| UEQUAL |count|)
-  (|coerceConvertMmSelection| |hash| UEQUAL |count|)
-; (|getModemapsFromDatabase| |hash| UEQUAL |count|)
-; (|getOperationAlistFromLisplib| |hash| UEQUAL |count|)
-  (|isLegitimateMode| |hash| UEQUAL |count|)
-  (|isValidType| |hash| UEQUAL |count|)
-  (|resolveTT|   |hash| UEQUAL |count|)
-  (|selectMms1| |hash| UEQUAL |count|)
-  (|underDomainOf|   |hash| UEQUAL |count|)
-  (|findRetractMms| |hash| UEQUAL |count|)
-  (|getConstantFromDomain|  |hash| UEQUAL |count|)
-  (|interpLookup| |hash| UEQUAL |count|)
-;  (|isSubDomain|   |hash| UEQUAL |count|)
+  (|canCoerce| |hash| EQUAL |count|)
+  (|canCoerceFrom| |hash| EQUAL |count|)
+  (|coerceConvertMmSelection| |hash| EQUAL |count|)
+; (|getModemapsFromDatabase| |hash| EQUAL |count|)
+; (|getOperationAlistFromLisplib| |hash| EQUAL |count|)
+  (|isLegitimateMode| |hash| EQUAL |count|)
+  (|isValidType| |hash| EQUAL |count|)
+  (|resolveTT|   |hash| EQUAL |count|)
+  (|selectMms1| |hash| EQUAL |count|)
+  (|underDomainOf|   |hash| EQUAL |count|)
+  (|findRetractMms| |hash| EQUAL |count|)
+  (|getConstantFromDomain|  |hash| EQUAL |count|)
+  (|interpLookup| |hash| EQUAL |count|)
+;  (|isSubDomain|   |hash| EQUAL |count|)
 ))
 
 ;; the following symbol holds the canonical "failed" value
@@ -341,7 +337,6 @@
 
 (SETQ |$Integer| '(|Integer|))
 (SETQ |$ComplexInteger| (LIST '|Complex| |$Integer|))
-(SETQ |$NegativeInteger| '(|NegativeInteger|))
 (SETQ |$NonNegativeInteger| '(|NonNegativeInteger|))
 (SETQ |$PositiveInteger| '(|PositiveInteger|))
 (SETQ |$RationalNumber| '(|Fraction| (|Integer|)))
@@ -360,7 +355,6 @@
 (SETQ |$NoValue| '|$NoValue|)
 (SETQ |$NoValueMode| '|NoValueMode|)
 (SETQ |$DummyFunctorNames| '(|Mapping|))
-(SETQ |$form| NIL)
 (SETQ |$EmptyVector| (VECTOR))
 (SETQ |$Index| 0)
 (SETQ |$true| ''T)
@@ -411,6 +405,8 @@
      |String| |Boolean| |Symbol| |DoubleFloat| |PrimitiveArray| |Vector|
      |Matrix| |OneDimensionalArray| |TwoDimensionalArray| |U32Vector|
      |U32Matrix| |U16Vector| |U16Matrix| |U8Vector| |U8Matrix|
+     |I32Vector| |I32Matrix| |I16Vector| |I16Matrix| |I8Vector| |I8Matrix|
+     |U64Int| |PrimitiveTwoDimensionalArray|
      |DoubleFloatVector| |DoubleFloatMatrix| |ComplexDoubleFloatVector|
      |ComplexDoubleFloatMatrix| |Character| |SortedExponentVector|
      |HashState| ))
@@ -418,7 +414,7 @@
 (SETQ |$Zero| '(|Zero|))
 (SETQ |$One| '(|One|))
 (SETQ |$NonMentionableDomainNames|
-      '($ |Rep| |Record| |Union| |Mapping| |Enumeration|))
+      '(% |Rep| |Record| |Union| |Mapping| |Enumeration|))
 
 ;"  modemap:==  ( <map> (p e) (p e) ... (p e) )  "
 ;"  modemaplist:= ( modemap ... )  "
@@ -439,20 +435,6 @@
 
 (SETQ |$useConvertForCoercions| NIL)
 
-;; ---- start of initial settings for variables used in test.boot
-
-(SETQ |$runTestFlag| NIL)          ;; referenced by maPrin to stash
-                                   ;; output by recordAndPrint to not
-                                   ;; print type/time
-(SETQ |$mkTestFlag| NIL)           ;; referenced by READLN to stash input
-                                   ;; by maPrin to stash output
-                                   ;; by recordAndPrint to write i/o
-                                   ;; onto $testStream
-(SETQ |$mkTestOutputStack| NIL)    ;; saves output for $testStream
-                                   ;; (see maPrin)
-
-;; ---- end of initial settings for variables used in test.boot
-
 
 
 (setq credits '(
