@@ -751,14 +751,15 @@ connect_to_local_server(char *server_name, int purpose, int time_out)
     free(sock);
     return NULL;
   }
+#ifndef HAVE_SOCKADDR_UN
+  return NULL;
+#else
   /* connect socket using name specified in command line */
-  memset(server[1].addr.u_addr.sa_data, 0,
-         sizeof(server[1].addr.u_addr.sa_data));
-  sock->addr.u_addr.sa_family = FRICAS_AF_LOCAL;
-  strcpy(sock->addr.u_addr.sa_data, name);
+  struct sockaddr_un *uaddr = &(sock->addr.u_addr);
+  uaddr->sun_family = FRICAS_AF_LOCAL;
+  strncpy(uaddr->sun_path, name, sizeof(uaddr->sun_path) - 1);
   for(i=0; i<max_con; i++) {
-    code = connect(sock->socket, &sock->addr.u_addr,
-                   sizeof(sock->addr.u_addr));
+    code = connect(sock->socket, uaddr, sizeof(*uaddr));
     if (code == -1) {
       if (
         /* @@@ Why we need this */
@@ -785,6 +786,7 @@ connect_to_local_server(char *server_name, int purpose, int time_out)
 /*  fprintf(stderr, "Got int form socket\n"); */
   sock->remote = get_int(sock);
   return sock;
+#endif
 }
 
 /* act as terminal session for sock connected to stdin and stdout of another
@@ -805,15 +807,16 @@ remote_stdio(Sock *sock)
       return;
     }
     if (FD_ISSET(0, &rd)) {
-      fgets(buf,1024,stdin);
-      len = strlen(buf);
-      /*
-          gets(buf);
-          len = strlen(buf);
-          *(buf+len) = '\n';
-          *(buf+len+1) = '\0';
-      */
-      swrite(sock, buf, len, "writing to remote stdin");
+      len = read(0, buf, 1024);
+      if (len == -1) {
+        perror("read from stdin");
+        return;
+      }
+      if (len == 0) {
+        /* EOF (CTRL-D) received, ignore it for now */
+      } else {
+        swrite(sock, buf, len, "writing to remote stdin");
+      }
     }
     if (FD_ISSET(sock->socket, &rd)) {
       len = sread(sock, buf, 1024, "stdio");
@@ -881,9 +884,11 @@ open_server(char *server_name)
 
   init_socks();
 #ifndef HAVE_MSG_NOSIGNAL
+#ifndef HAVE_SO_NOSIGPIPE
 #ifdef SIGPIPE
   bsdSignal(SIGPIPE, sigpipe_handler,RestartSystemCalls);
 #endif
+#endif
 #endif
   if (make_server_name(name, server_name) == -1)
     return -2;
@@ -914,25 +919,34 @@ open_server(char *server_name)
     listen(server[0].socket,5);
   } */
   /* Next create the local domain socket */
+#ifndef HAVE_SOCKADDR_UN
+  server[1].socket = 0;
+  return -1;
+#else
   server[1].socket = fricas_communication_link(FRICAS_AF_LOCAL);
   if (is_invalid_socket(&server[1])) {
     perror("opening local server socket");
     server[1].socket = 0;
     return -2;
   } else {
-    server[1].addr.u_addr.sa_family = FRICAS_AF_LOCAL;
-    memset(server[1].addr.u_addr.sa_data, 0,
-           sizeof(server[1].addr.u_addr.sa_data));
-    strcpy(server[1].addr.u_addr.sa_data, name);
-    if (bind(server[1].socket, &server[1].addr.u_addr,
-             sizeof(server[1].addr.u_addr))) {
+    Sock * sock = &(server[1]);
+    struct sockaddr_un * uaddr = &(sock->addr.u_addr);
+    uaddr->sun_family = FRICAS_AF_LOCAL;
+    strncpy(uaddr->sun_path, name, sizeof(uaddr->sun_path) - 1);
+    if (bind(sock->socket, uaddr, sizeof(*uaddr))) {
       perror("binding local server socket");
       server[1].socket = 0;
       return -2;
     }
-    FD_SET(server[1].socket, &socket_mask);
-    FD_SET(server[1].socket, &server_mask);
-    listen(server[1].socket, 5);
+#ifdef HAVE_SO_NOSIGPIPE
+    /* macOS doesn't have MSG_NOSIGNAL, so use SO_NOSIGPIPE instead */
+    int set = 1;
+    setsockopt(sock->socket, SOL_SOCKET, SO_NOSIGPIPE,
+               (void *)&set, sizeof(int));
+#endif
+    FD_SET(sock->socket, &socket_mask);
+    FD_SET(sock->socket, &server_mask);
+    listen(sock->socket, 5);
   }
   s = getenv("SPADSERVER");
   if (s == NULL) {
@@ -940,6 +954,7 @@ open_server(char *server_name)
     return -1;
   }
   return 0;
+#endif
 }
 
 int
@@ -1108,47 +1123,3 @@ print_line(char *s)
   printf("%s\n", s);
 }
 
-
-typedef union {
-  double        f;
-  long          l[2];
-        } DoubleFloat;
-
-double
-plus_infinity(void )
-{
-  static int init = 0;
-  static DoubleFloat pinf;
-  if (! init) {
-    pinf.l[0] = 0x7ff00000;
-    pinf.l[1] = 0;
-    init = 1;
-  }
-  return pinf.f;
-}
-
-double
-minus_infinity(void)
-{
-  static int init = 0;
-  static DoubleFloat minf;
-  if (! init) {
-    minf.l[0] = 0xfff00000L;
-    minf.l[1] = 0;
-    init = 1;
-  }
-  return minf.f;
-}
-
-double
-NANQ(void)
-{
-  static int init = 0;
-  static DoubleFloat nanq;
-  if (! init) {
-    nanq.l[0] = 0x7ff80000L;
-    nanq.l[1] = 0;
-    init = 1;
-  }
-  return nanq.f;
-}
